@@ -98,6 +98,9 @@ class JManFb:
     def c_sync_comandes_pendents(self):
         return self.select(sql=fb_consultes.sync_comandes_pendents)
 
+    def c_sync_moviments_magatzems_pendents(self, p_magatzem_entrada_id: int):
+        return self.select(sql=fb_consultes.sync_moviments_magatzems_pendents, args=(p_magatzem_entrada_id,))
+
     def c_sync_comanda(self, comanda_id: int):
         return self.select(sql=fb_consultes.sync_comanda, args=(comanda_id,))[0]
 
