@@ -35,6 +35,7 @@ select
     c.EMPRESA_ID, 
     c.ID COMANDA_ID,
     c.NUMERO_COMANDA,
+    c.REFERENCIA,
     cd.TERCER_ID CLIENT_ID,
     cd.REPARTIDOR_ID,
     CASE WHEN c_cli.COMANDA_ID IS NULL THEN cd_ter.NOM_LLARG_I_COMERCIAL ELSE c_cli.TERCER END NOM_CLIENT,
@@ -45,7 +46,7 @@ select
     CASE WHEN c_cli.COMANDA_ID IS NULL THEN NULL ELSE c_cli.TELEFON END TELEFON,
     CASE WHEN c_cli.COMANDA_ID IS NULL THEN NULL ELSE c_cli.EMAIL END MAIL,
     cd.PES_NET, cd.PES_BRUT
-    
+
 from comandes c
 join comandes_distribucio cd on c.ID = cd.COMANDA_ID
 join adreces_distribucio cd_adr on cd.ADRECA_DISTRIBUCIO_ID = cd_adr.ID
@@ -89,6 +90,16 @@ where C.DATA_INICI IS NULL AND CE.MAG_PENDENT_SERVIR = 'S' AND C.DATA_ANULACIO I
   and CD.REPARTIDOR_ID IS NOT NULL ;
 """
 
+sync_moviments_magatzems_pendents = """
+SELECT MO.ID,MO.NUMERO_ORDRE, MO.DATA_INSERCIO, MO.MAGATZEM_ORDRE,MO.MAGATZEM_SORTIDA_ID, MO.MAGATZEM_ENTRADA_ID ,MO.OBSERVACIONS, U.NUMERO_UNITAT
+FROM MAGATZEMS_ORDRES MO
+JOIN MAGATZEMS_ORDRES_DETALL MD ON MO.ID = MD.MAGATZEM_ORDRE_ID
+JOIN UNITATS_LOGISTIQUES U ON U.ID = MD.UNITAT_LOGISTICA_ID
+where MO.DATA_BLOQUEIG IS null
+AND MO.DATA_CONFIRMACIO IS NOT null
+AND MO.DATA_FINALITZACIO IS NULL
+AND MO.MAGATZEM_ENTRADA_ID = ? ;
+"""
 
 sync_clients_mrest = """
         select cl.id client_id_client,
